parse_ticker_to_option_greeks

Function parse_ticker_to_option_greeks 

pub fn parse_ticker_to_option_greeks(
    msg: &DeribitTickerMsg,
    instrument: &InstrumentAny,
    ts_init: UnixNanos,
) -> Option<OptionGreeks>
Parses a Deribit ticker message into a Nautilus OptionGreeks.

Returns None if the ticker message does not contain Greeks (non-option instrument).